@@ -1,9 +1,9 @@
 #ifndef PHP_MSGPACK_H
 #define PHP_MSGPACK_H
 
-#include "ext/standard/php_smart_str.h" /* for smart_str */
+#include "Zend/zend_smart_str.h" /* for smart_string */
 
-#define PHP_MSGPACK_VERSION "0.5.6"
+#define PHP_MSGPACK_VERSION "2.0.3"
 
 extern zend_module_entry msgpack_module_entry;
 #define phpext_msgpack_ptr &msgpack_module_entry
@@ -24,6 +24,7 @@ ZEND_BEGIN_MODULE_GLOBALS(msgpack)
     zend_bool error_display;
     zend_bool php_only;
     zend_bool illegal_key_insert;
+    zend_bool use_str8_serialization;
     struct {
         void *var_hash;
         unsigned level;
@@ -39,8 +40,8 @@ ZEND_EXTERN_MODULE_GLOBALS(msgpack)
 #endif
 
 PHP_MSGPACK_API void php_msgpack_serialize(
-    smart_str *buf, zval *val TSRMLS_DC);
-PHP_MSGPACK_API void php_msgpack_unserialize(
-    zval *return_value, char *str, size_t str_len TSRMLS_DC);
+    smart_str *buf, zval *val);
+PHP_MSGPACK_API int php_msgpack_unserialize(
+    zval *return_value, char *str, size_t str_len);
 
 #endif  /* PHP_MSGPACK_H */
